@@ -26,23 +26,23 @@
 
 void sj_stock_init (void);
 
-void on_quit_activate (GtkMenuItem *item, gpointer user_data);
-void on_destroy_activate (GtkMenuItem *item, gpointer user_data);
-void on_eject_activate (GtkMenuItem *item, gpointer user_data);
-void on_select_all_activate (GtkMenuItem *item, gpointer user_data);
-void on_deselect_all_activate (GtkMenuItem *item, gpointer user_data);
-void on_destroy_signal (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_quit_activate (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_destroy_activate (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_eject_activate (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_select_all_activate (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_deselect_all_activate (GtkMenuItem *item, gpointer user_data);
+G_MODULE_EXPORT void on_destroy_signal (GtkMenuItem *item, gpointer user_data);
 
 AlbumDetails* multiple_album_dialog (GList* albums);
 
 const char* prefs_get_default_device (void);
 
-void on_reread_activate (GtkWidget *button, gpointer user_data);
-void on_submit_activate (GtkWidget *menuitem, gpointer user_data);
-void on_genre_edit_changed(GtkEditable *widget, gpointer user_data);
-void on_year_edit_changed(GtkEditable *widget, gpointer user_data);
-void on_contents_activate(GtkWidget *button, gpointer user_data);
-void on_duplicate_activate (GtkWidget *button, gpointer user_data);
+G_MODULE_EXPORT void on_reread_activate (GtkWidget *button, gpointer user_data);
+G_MODULE_EXPORT void on_submit_activate (GtkWidget *menuitem, gpointer user_data);
+G_MODULE_EXPORT void on_genre_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_year_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_contents_activate(GtkWidget *button, gpointer user_data);
+G_MODULE_EXPORT void on_duplicate_activate (GtkWidget *button, gpointer user_data);
 
 GtkWidget* sj_make_volume_button (void);
 
