@@ -84,7 +84,7 @@ select_track (void)
  * Start playing.
  */
 static void
-play (void)
+_play (void)
 {
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
   
@@ -96,7 +96,7 @@ play (void)
  * Pause
  */
 static void
-pause (void)
+_pause (void)
 {
   gst_element_set_state (pipeline, GST_STATE_PAUSED);
 }
@@ -105,7 +105,7 @@ pause (void)
  * Stop and reset UI.
  */
 static void
-stop (void)
+_stop (void)
 {
   if (pipeline != NULL)
     gst_element_set_state (pipeline, GST_STATE_NULL);
@@ -173,7 +173,7 @@ cb_hop_track (GstBus *bus, GstMessage *message, gpointer user_data)
   }
 
   if (next_track >= tracks) {
-    stop ();
+    _stop ();
     seek_to_track = 0;
   } else {
     seek_to_track = next_track;
@@ -200,7 +200,7 @@ cb_error (GstBus *bus, GstMessage *message, gpointer user_data)
   /* There may be other (more generic) error messages on the bus; set pipeline
    * to NULL state so these messages are flushed from the bus and we don't get
    * called again for those */
-  stop ();
+  _stop ();
 }
 
 static gchar *
@@ -373,6 +373,10 @@ setup (GError **err)
     	              "read-speed", 2,
                       NULL);
     }
+    /* Disable paranoia in playback mode */
+    if (g_object_class_find_property (G_OBJECT_GET_CLASS (cdp), "paranoia-mode"))
+      g_object_set (cdp, "paranoia-mode", 0, NULL);
+
     g_object_set (G_OBJECT (cdp),
                   "device", brasero_drive_get_device (drive),
                   NULL);
@@ -423,25 +427,25 @@ setup (GError **err)
 void
 stop_playback (void)
 {
-  stop ();
+  _stop ();
 }
 
 /*
  * Interface entry point.
  */
 
-void
+G_MODULE_EXPORT void
 on_play_activate (GtkWidget *button, gpointer user_data)
 {
   GError *err = NULL;
 
   if (is_playing ()) {
-    pause ();
+    _pause ();
     gtk_list_store_set (track_store, &current_iter,
                         COLUMN_STATE, STATE_PAUSED, -1);
  } else if (pipeline && GST_STATE (pipeline) == GST_STATE_PAUSED && 
              current_track == seek_to_track) {
-    play ();
+    _play ();
     gtk_list_store_set (track_store, &current_iter,
                         COLUMN_STATE, STATE_PLAYING, -1);
   } else if (pipeline && GST_STATE (pipeline) == GST_STATE_PAUSED &&
@@ -466,7 +470,7 @@ on_play_activate (GtkWidget *button, gpointer user_data)
   }
 }
 
-void
+G_MODULE_EXPORT void
 on_tracklist_row_activate (GtkTreeView * treeview, GtkTreePath * path,
     GtkTreeViewColumn * col, gpointer user_data)
 {
@@ -495,13 +499,13 @@ on_tracklist_row_activate (GtkTreeView * treeview, GtkTreePath * path,
   }
 }
 
-void
+G_MODULE_EXPORT void
 on_next_track_activate(GtkWidget *button, gpointer data)
 {
   cb_hop_track (NULL, NULL, NULL);
 }
 
-void
+G_MODULE_EXPORT void
 on_previous_track_activate(GtkWidget *button, gpointer data)
 {
   GtkTreeModel *model;
@@ -524,7 +528,7 @@ on_previous_track_activate(GtkWidget *button, gpointer data)
   }
 
   if (prev_track < 0) {
-    stop ();
+    _stop ();
     seek_to_track = 0;
   } else {
     seek_to_track = prev_track;
@@ -546,14 +550,14 @@ set_gst_ui_and_play (void)
         &current_iter, COLUMN_TITLE, &title, -1);
     sj_main_set_title (title);
     g_free (title);
-    play ();
+    _play ();
   } else {
     g_warning (G_STRLOC ": failed to select track");
-    stop ();
+    _stop ();
   }
 }
 
-void
+G_MODULE_EXPORT void
 on_tracklist_row_selected (GtkTreeView *treeview,
                gpointer user_data)
 {
@@ -574,7 +578,7 @@ on_tracklist_row_selected (GtkTreeView *treeview,
  * Volume.
  */
 
-void
+G_MODULE_EXPORT void
 on_volume_changed (GtkWidget * volb, gdouble value, gpointer data)
 {
   vol = value;
@@ -591,7 +595,7 @@ on_volume_changed (GtkWidget * volb, gdouble value, gpointer data)
  * Seeking.
  */
 
-gboolean
+G_MODULE_EXPORT gboolean
 on_seek_press (GtkWidget * scale, GdkEventButton * event, gpointer user_data)
 {
   seeking = TRUE;
@@ -599,7 +603,7 @@ on_seek_press (GtkWidget * scale, GdkEventButton * event, gpointer user_data)
   return FALSE;
 }
 
-void
+G_MODULE_EXPORT void
 on_seek_moved (GtkWidget * scale, gpointer user_data)
 {
   gdouble val = gtk_range_get_value (GTK_RANGE (scale));
@@ -615,7 +619,7 @@ on_seek_moved (GtkWidget * scale, gpointer user_data)
   g_free (m);
 }
 
-gboolean
+G_MODULE_EXPORT gboolean
 on_seek_release (GtkWidget * scale, GdkEventButton * event, gpointer user_data)
 {
   gdouble val = gtk_range_get_value (GTK_RANGE (scale));
@@ -653,12 +657,12 @@ stop_ui_hack (void)
 void
 sj_play_init (void)
 {
-  play_button = glade_xml_get_widget (glade, "play_button");
-  next_menuitem = glade_xml_get_widget (glade, "next_track_menuitem");
-  prev_menuitem = glade_xml_get_widget (glade, "previous_track_menuitem");
-  reread_menuitem = glade_xml_get_widget (glade, "re-read");
-  seek_scale = glade_xml_get_widget (glade, "seek_scale");
-  volume_button = glade_xml_get_widget (glade, "volume_button");
-  statusbar = glade_xml_get_widget (glade, "status_bar");
-  track_listview = glade_xml_get_widget (glade, "track_listview");
+  play_button     = GET_WIDGET ("play_button");
+  next_menuitem   = GET_WIDGET ("next_track_menuitem");
+  prev_menuitem   = GET_WIDGET ("previous_track_menuitem");
+  reread_menuitem = GET_WIDGET ("re-read");
+  seek_scale      = GET_WIDGET ("seek_scale");
+  volume_button   = GET_WIDGET ("volume_button");
+  statusbar       = GET_WIDGET ("status_bar");
+  track_listview  = GET_WIDGET ("track_listview");
 }
